@@ -168,10 +168,8 @@ class NxPyDocs():
         os.chdir("nxpydocs")           
 
     def send_to_repo(self):
-        os.system("git status")
         os.system("git add *")
-        os.system("git commit -am 'nxpydocs generated this commit")
-        os.system("git status")
+        os.system("git commit -am 'nxpydocs generated this commit'")
         os.system("git push")
 
 @click.command()
